summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/registeritem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/registeritem.h')
-rw-r--r--kmymoney2/widgets/registeritem.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/kmymoney2/widgets/registeritem.h b/kmymoney2/widgets/registeritem.h
index 84afa84..b75de1b 100644
--- a/kmymoney2/widgets/registeritem.h
+++ b/kmymoney2/widgets/registeritem.h
@@ -21,9 +21,9 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qstring.h>
-#include <qdatetime.h>
-#include <qpainter.h>
+#include <tqstring.h>
+#include <tqdatetime.h>
+#include <tqpainter.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -46,7 +46,7 @@ typedef enum {
typedef enum {
ActionNone = -1,
ActionCheck = 0,
- /* these should be values which qt 3.3 never uses for QTab:
+ /* these should be values which qt 3.3 never uses for TQTab:
* qt starts upwards from 0
*/
ActionDeposit = 12201,
@@ -67,7 +67,7 @@ class RegisterItem
{
public:
RegisterItem();
- RegisterItem(Register* parent);
+ RegisterItem(Register* tqparent);
virtual ~RegisterItem();
virtual const char* className(void) = 0;
@@ -85,17 +85,17 @@ public:
virtual bool isErronous(void) const = 0;
// helper functions used for sorting
- virtual const QDate& sortPostDate(void) const { return nullDate; }
+ virtual const TQDate& sortPostDate(void) const { return nullDate; }
virtual int sortSamePostDate(void) const = 0;
- virtual const QDate& sortEntryDate(void) const { return nullDate; }
- virtual const QString& sortPayee(void) const { return QString::null; }
+ virtual const TQDate& sortEntryDate(void) const { return nullDate; }
+ virtual const TQString& sortPayee(void) const { return TQString(); }
virtual const MyMoneyMoney& sortValue(void) const { return nullValue; }
- virtual const QString& sortNumber(void) const { return QString::null; }
- virtual const QString& sortEntryOrder(void) const { return QString::null; }
+ virtual const TQString& sortNumber(void) const { return TQString(); }
+ virtual const TQString& sortEntryOrder(void) const { return TQString(); }
virtual CashFlowDirection sortType(void) const { return Deposit; }
- virtual const QString& sortCategory(void) const { return QString::null; }
+ virtual const TQString& sortCategory(void) const { return TQString(); }
virtual MyMoneySplit::reconcileFlagE sortReconcileState(void) const { return MyMoneySplit::MaxReconcileState; }
- virtual const QString& sortSecurity(void) const { return QString::null; }
+ virtual const TQString& sortSecurity(void) const { return TQString(); }
/**
* This method sets the row offset of the item in the register
@@ -103,7 +103,7 @@ public:
*
* @param row row offset
*
- * @note The row offset is based on QTable rows, not register
+ * @note The row offset is based on TQTable rows, not register
* items.
*/
virtual void setStartRow(int row) { m_startRow = row; }
@@ -144,24 +144,24 @@ public:
*/
virtual void setAlternate(bool alternate) { m_alternate = alternate; }
- virtual void paintRegisterCell(QPainter* painter, int row, int col, const QRect& r, bool selected, const QColorGroup& cg) = 0;
- virtual void paintFormCell(QPainter* painter, int row, int col, const QRect& r, bool selected, const QColorGroup& cg) = 0;
+ virtual void paintRegisterCell(TQPainter* painter, int row, int col, const TQRect& r, bool selected, const TQColorGroup& cg) = 0;
+ virtual void paintFormCell(TQPainter* painter, int row, int col, const TQRect& r, bool selected, const TQColorGroup& cg) = 0;
- virtual const QString& id(void) const { return MyMoneyObject::emptyId(); }
+ virtual const TQString& id(void) const { return MyMoneyObject::emptyId(); }
/**
* Sets the parent of this item to be the register @p parent
*
* @param parent pointer to register
*/
- void setParent(Register* parent);
+ void setParent(Register* tqparent);
/**
* This member returns a pointer to the parent object
*
* @retval pointer to Register
*/
- Register* parent(void) const { return m_parent; }
+ Register* tqparent(void) const { return m_parent; }
void setNeedResize(void) { m_needResize = true; }
@@ -185,7 +185,7 @@ public:
RegisterItem* nextItem(void) const { return m_next; }
RegisterItem* prevItem(void) const { return m_prev; }
- virtual bool matches(const QString&) const = 0;
+ virtual bool matches(const TQString&) const = 0;
/**
* Checks if the mouse hovered over an area that has a tooltip associated with it.
@@ -194,11 +194,11 @@ public:
*
* If a tooltip shall be shown, this method presets the rectangle @a r with the
* area in register coordinates and @a msg with the string that will be passed
- * to QToolTip::tip. @a true is returned in this case.
+ * to TQToolTip::tip. @a true is returned in this case.
*
* If no tooltip is available, @a false will be returned.
*/
- virtual bool maybeTip(const QPoint& /* relpos */, int /* row */, int /* col */, QRect& /* r */, QString& /* msg */) { return false; }
+ virtual bool maybeTip(const TQPoint& /* relpos */, int /* row */, int /* col */, TQRect& /* r */, TQString& /* msg */) { return false; }
protected:
/// This method serves as helper for all constructors
@@ -216,7 +216,7 @@ protected:
bool m_visible;
private:
- static QDate nullDate;
+ static TQDate nullDate;
static MyMoneyMoney nullValue;
};
@@ -144,24 +144,24 @@ public:
/**
- * Sets the parent of this item to be the register @p parent
+ * Sets the tqparent of this item to be the register @p tqparent
*
@@ -144,24 +144,24 @@ public:
*
- * @param parent pointer to register
+ * @param tqparent pointer to register
*/
@@ -144,24 +144,24 @@ public:
/**
- * This member returns a pointer to the parent object
+ * This member returns a pointer to the tqparent object
*
* @retval pointer to Register